/*
 * Copyright 2011 Jeroen Meetsma
 *
 *
 * This file is part of Iglu.
 *
 * Iglu is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Iglu is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Iglu.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.ijsberg.iglu.util.io;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Forwards received messages to a transmitter.
 */
public class Forwarder implements Receiver {
	private OutputStream outputStream;
	private Transmitter outputTransmitter;

	public Forwarder(Transmitter outputTransmitter) {
		this.outputTransmitter = outputTransmitter;
	}


	public Forwarder(OutputStream outputStream) {
		this.outputStream = outputStream;
	}

	public void onReceive(Object message) {
		if (outputTransmitter != null) {
			outputTransmitter.transmit(message);
		}
		else {
			try {
				if (message instanceof byte[]) {
					outputStream.write((byte[]) message);
				}
				else {
					outputStream.write(message.toString().getBytes());
				}
			}
			catch (IOException ioe) {
				//...
			}
		}
	}

	public void onTransmissionClose() {
		try {
			outputStream.close();
		}
		catch (IOException ioe) {
			//...
		}
	}

	public void close() {
		try {
			outputStream.close();
		}
		catch (IOException ioe) {
			//...
		}
	}
}
